
/* texcoords*/
varying vec2 texcoord0;
varying vec2 texdim0;
varying vec2 texcoord1;

varying vec2 texdim1;

/* samplers*/
uniform sampler2DRect tex0;

uniform sampler2DRect tex1;

uniform vec4 outColor;

uniform bool useOutTex;

/* resample dimensions*/
uniform vec4 crop;

uniform vec4 edge;

uniform int edgeMode;

uniform vec4 edgeColor;

uniform vec2 zoom ; 
uniform vec2 offset ;



uniform float interp;


uniform bool invert;


void main()
{	
	/* ramene coord [0-1] sur [0-texdim]*/
	vec4 cm = crop*vec4(texdim0.xyxy); /* coord crop*/
	
	vec4 am = edge*vec4(texdim0.xyxy); /* coord edge*/

	/* calcul coord pixel fct zoom et offset*/
	vec2 fragcoord ;
	fragcoord = texcoord0/zoom - offset*texdim0 ; 
	
	/* verifie que dans borne du crop*/
	bool bnd = all(bvec4(texcoord0.x>cm.x,texcoord0.x<cm.z,texcoord0.y>cm.y,texcoord0.y<cm.w));

	/* recupere couleur pixel*/
	vec4 fragColor = texture2DRect(tex0,mix(floor(fragcoord),fragcoord,interp));
	float alpha = fragColor.a ; 
	vec4 fragOutColor ;
	if (useOutTex) fragOutColor = texture2DRect(tex1,texcoord1);
	else fragOutColor = outColor ; 
	
	/* alpha blending hors des bornes*/

	if (bnd) {
		/* edgeblend */
		if (edgeMode == 1){	

			float ax = 1.;
			float ay = 1.; 

			
			if (texcoord0.x<cm.x + am.x){
				ax = smoothstep (cm.x, cm.x+am.x, texcoord0.x) ;
			}else if (texcoord0.x>cm.z - am.z){
				ax = smoothstep (cm.z, cm.z-am.z, texcoord0.x) ;
			}
			if (texcoord0.y<cm.y + am.y){
				ay = smoothstep (cm.y, cm.y+am.y, texcoord0.y) ;
			}else if (texcoord0.y>cm.w - am.w){
				ay = smoothstep (cm.w, cm.w-am.w, texcoord0.y) ;
			}		
			float r = clamp(ax*ay, 0., alpha);
			
			
			if (invert) fragColor = mix (fragColor, fragOutColor, r);
			
			else fragColor = mix (fragOutColor, fragColor, r);

		} 
		
		/* edgeBorder */
		
		else if(edgeMode == 2) {
			
			if (texcoord0.x<cm.x + am.x || texcoord0.x>cm.z - am.z || texcoord0.y<cm.y + am.y || texcoord0.y>cm.w - am.w){
					fragColor = edgeColor ;
			}
			else{
				
				if (invert) fragColor = fragOutColor;
			
			}
		
		}
	}
	else {
		if (!invert) fragColor = fragOutColor ;
	}


	gl_FragColor = fragColor ;

}
